==> sddm_0.13.0.orig.tar.xz: sddm-0.13.0/data/translations/zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>歡迎來到 %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>警告，目前 Caps Lock 是開啟的狀態！</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>佈局</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登入</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>登入失敗</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>登入成功</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>輸入您的使用者名稱與密碼</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新開機</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>工作階段</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>選取您的使用者並輸入密碼</translation>
    </message>
</context>
</TS>

==> sddm-0.16.0.tar.xz: sddm-0.16.0/data/translations/zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>PictureBox</name>
    <message>
        <source>Press to login</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 (Wayland)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextConstants</name>
    <message>
        <source>Welcome to %1</source>
        <translation>歡迎來到 %1</translation>
    </message>
    <message>
        <source>Warning, Caps Lock is ON!</source>
        <translation>警告，目前 Caps Lock 是開啟的狀態！</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>佈局</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登入</translation>
    </message>
    <message>
        <source>Login failed</source>
        <translation>登入失敗</translation>
    </message>
    <message>
        <source>Login succeeded</source>
        <translation>登入成功</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>密碼</translation>
    </message>
    <message>
        <source>Enter your username and password</source>
        <translation>輸入您的使用者名稱與密碼</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新開機</translation>
    </message>
    <message>
        <source>Session</source>
        <translation>工作階段</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>User name</source>
        <translation>使用者名稱</translation>
    </message>
    <message>
        <source>Select your user and enter password</source>
        <translation>選取您的使用者並輸入密碼</translation>
    </message>
</context>
</TS>
